| cite_fude | R Documentation |
cite_fude() generates citation text in Japanese and English from Fude
Polygon data and related boundary data.
cite_fude(data)
data |
A Fude Polygon data object, boundary data object, or a data frame/list
containing |
A list with two elements: ja for Japanese citation text and en for
English citation text.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.