View source: R/extract_boundary.R
| extract_boundary | R Documentation |
extract_boundary() extracts subsets of agricultural community boundary data
returned by get_boundary() by municipality, former municipality, and/or
agricultural community.
extract_boundary(boundary, city = "", kcity = "", rcom = "", layer = FALSE)
boundary |
Agricultural community boundary data returned by |
city |
A character vector of municipality names or local government codes used to
identify target municipalities. If |
kcity |
A character vector of regular expression patterns used to match former municipality names in Japanese. |
rcom |
A character vector of regular expression patterns used to match agricultural community names in Japanese. |
layer |
Logical. If |
If layer = FALSE, an sf::sf() object. If layer = TRUE, a named list of
sf::sf() objects.
get_boundary()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.