| extract_fude | R Documentation |
extract_fude() extracts a subset of Fude Polygon data returned by
read_fude() by year, municipality, former municipality, and/or
agricultural community.
extract_fude(data, year = NULL, city = NULL, kcity = "", rcom = "")
data |
A Fude Polygon data object returned by |
year |
A numeric vector of issue years to extract. If |
city |
A character vector of municipality names or local government codes used to
identify target municipalities. If |
kcity |
A character vector of regular expression patterns used to match former municipality names in Japanese. |
rcom |
A character vector of regular expression patterns used to match agricultural community names in Japanese. |
An sf::sf() object containing the extracted subset.
read_fude()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.