read_ikasudb: Read a shuraku excel file

View source: R/read_ikasudb.R

read_ikasudbR Documentation

Read a shuraku excel file

Description

read_ikasudb() reads a shuraku Excel file provided by MAFF and joins its tabular contents to agricultural community boundary data.

Usage

read_ikasudb(boundary, path, na = c("-", "…"), zero = TRUE)

Arguments

boundary

Agricultural community boundary data, typically returned by get_boundary(). This can be a single boundary object or a list of boundary objects.

path

Path to an .xlsx file provided by MAFF or a .csv file

na

Character vector of strings to interpret as missing values. Defaults to c("-", "\u2026").

zero

Logical. If TRUE, treat masked values ("x" and "X") as zero before numeric conversion.

Value

An sf::sf() object created by joining the Excel data to boundary.

See Also

read_fude()


fude documentation built on April 5, 2026, 9:06 a.m.