bind_fude: Bind multiple Fude Polygon data objects

View source: R/bind_fude.R

bind_fudeR Documentation

Bind multiple Fude Polygon data objects

Description

bind_fude() combines multiple Fude Polygon data objects by binding elements with the same names across inputs. It can also be used on objects that have already been combined by combine_fude().

Usage

bind_fude(...)

Arguments

...

Two or more Fude Polygon data objects to combine. Named elements that appear in multiple inputs are row-bound into a single sf::sf() object.

Value

A named list of sf::sf() objects.

See Also

combine_fude()

Examples

path <- system.file("extdata", "castle.zip", package = "fude")
d1 <- read_fude(path, quiet = TRUE)
d2 <- read_fude(path, quiet = TRUE)
bind_fude(d1, d2)


fude documentation built on April 5, 2026, 9:06 a.m.