| bind_fude | R Documentation |
bind_fude() combines multiple Fude Polygon data objects by binding elements
with the same names across inputs. It can also be used on objects that have
already been combined by combine_fude().
bind_fude(...)
... |
Two or more Fude Polygon data objects to combine. Named elements that appear
in multiple inputs are row-bound into a single |
A named list of sf::sf() objects.
combine_fude()
path <- system.file("extdata", "castle.zip", package = "fude")
d1 <- read_fude(path, quiet = TRUE)
d2 <- read_fude(path, quiet = TRUE)
bind_fude(d1, d2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.