| combine_fude | R Documentation |
combine_fude() combines Fude Polygon data with agricultural community
boundary data and returns the polygons associated with the specified
municipality, former municipality, and/or agricultural community.
combine_fude(data, boundary, city, kcity = "", rcom = "", year = NULL)
data |
A Fude Polygon data object returned by |
boundary |
Agricultural community boundary data returned by |
city |
A character vector of municipality names or local government codes used to
identify target municipalities. If |
kcity |
A character vector of regular expression patterns used to match former municipality names in Japanese. |
rcom |
A character vector of regular expression patterns used to match agricultural community names in Japanese. |
year |
Numeric scalar or |
A named list of sf::sf() objects.
read_fude(), get_boundary()
path <- system.file("extdata", "castle.zip", package = "fude")
d <- read_fude(path)
b <- get_boundary(d)
db <- combine_fude(d, b, "\u677e\u5c71\u5e02", "\u57ce\u6771", year = 2022)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.