Combine the Fude Polygon data with the agricultural community boundary data
Source:R/combine_fude.R
combine_fude.Rdcombine_fude() uses the agricultural community boundary data to reduce the
Fude Polygon data to the community units.
Arguments
- data
Fude Polygon data as returned by
read_fude().- boundary
Agricultural community boundary data as returned by
get_boundary().- city
A character vector of local government names or 6-digit local government codes to extract.
- kcity
A regular expression. One or more former municipality names (in Japanese) to extract.
- rcom
A regular expression. One or more agricultural community names (in Japanese) to extract.
- year
Year in the column name of the
data. If there is more than one applicable local government code, it is required.
Value
A list of sf::sf() objects.
Examples
if (FALSE) { # interactive()
path <- system.file("extdata", "castle.zip", package = "fude")
d <- read_fude(path, stringsAsFactors = FALSE)
b <- get_boundary(d)
db <- combine_fude(d, b, "\u677e\u5c71\u5e02", "\u57ce\u6771", year = 2022)
}