Extract specified agricultural community boundary data
Source:R/extract_boundary.R
extract_boundary.Rdextract_boundary() extracts subsets of agricultural community boundary data
returned by get_boundary() by municipality, former municipality, and/or
agricultural community.
Arguments
- boundary
Agricultural community boundary data returned by
get_boundary().- city
A character vector of municipality names or local government codes used to identify target municipalities. If
NULL, all municipalities are kept.- kcity
A character vector of regular expression patterns used to match former municipality names in Japanese.
- rcom
A character vector of regular expression patterns used to match agricultural community names in Japanese.
- layer
Logical. If
TRUE, return a list containing extracted agricultural community boundaries together with former municipality, municipality, and prefecture boundary layers.