| get_boundary | R Documentation |
get_boundary() downloads and reads one or more MAFF agricultural community
boundary datasets and returns them as a named list of sf::sf() objects.
The target prefectures are determined from data.
get_boundary(
data,
boundary_data_year = 2020,
rcom_year = 2020,
boundary_type = 1,
path = NULL,
suffix = FALSE,
crs = NULL,
encoding = "CP932",
quiet = FALSE
)
data |
Either a Fude Polygon data object returned by |
boundary_data_year |
The year of the boundary dataset. |
rcom_year |
The agricultural community reference year used in the MAFF file name. |
boundary_type |
Integer specifying the boundary level to read: |
path |
Path to a directory containing boundary ZIP files. If |
suffix |
Logical. If |
crs |
Coordinate reference system to transform the output data to. If |
encoding |
Character encoding of the source shapefile attributes, such as |
quiet |
Logical. If |
A named list of sf::sf() objects.
path <- system.file("extdata", "castle.zip", package = "fude")
d <- read_fude(path)
b <- get_boundary(d)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.