| ls_fude | R Documentation |
ls_fude() summarizes the contents of a Fude Polygon data object returned by
read_fude(). It reports the data name, issue year, local government code,
number of records, and corresponding prefecture and municipality names.
ls_fude(data)
data |
A Fude Polygon data object returned by |
A data frame with one row per combination of data name, issue year, and local government code.
read_fude()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.