Skip to contents

ls_fude() summarizes the contents of a Fude Polygon data object returned by read_fude(). It reports the data name, issue year, local government code, number of records, and corresponding prefecture and municipality names.

Usage

ls_fude(data)

Arguments

data

A Fude Polygon data object returned by read_fude().

Value

A data frame with one row per combination of data name, issue year, and local government code.

See also