ls_fude() lists the year and the local government names (or codes) in
order to understand what is included in the list returned by read_fude().
Arguments
- data
Fude Polygon data as returned by
read_fude().
ls_fude() lists the year and the local government names (or codes) in
order to understand what is included in the list returned by read_fude().
Fude Polygon data as returned by read_fude().