| read_ikasudb | R Documentation |
read_ikasudb() reads a shuraku Excel file provided by MAFF and joins its
tabular contents to agricultural community boundary data.
read_ikasudb(boundary, path, na = c("-", "…"), zero = TRUE)
boundary |
Agricultural community boundary data, typically returned by |
path |
Path to an |
na |
Character vector of strings to interpret as missing values. Defaults to
|
zero |
Logical. If |
An sf::sf() object created by joining the Excel data to boundary.
read_fude()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.