read_ikasudb() reads a shuraku Excel file provided by MAFF and joins its
tabular contents to agricultural community boundary data.
Usage
read_ikasudb(boundary, path, na = c("-", "…"), zero = TRUE)Arguments
- boundary
Agricultural community boundary data, typically returned by
get_boundary(). This can be a single boundary object or a list of boundary objects.- path
Path to an
.xlsxfile.- na
Character vector of strings to interpret as missing values. Defaults to
c("-", "\u2026").- zero
Logical. If
TRUE, treat masked values ("x"and"X") as zero before numeric conversion.
Value
An sf::sf() object created by joining the Excel data to boundary.