| rename_fude | R Documentation |
rename_fude() renames the elements of a Fude Polygon data object returned
by read_fude() by replacing local government codes in the element names
with corresponding municipality names, making the object easier to read.
rename_fude(data, suffix = TRUE, romaji = NULL, quiet = TRUE)
data |
A Fude Polygon data object returned by |
suffix |
Logical. If |
romaji |
Character scalar or |
quiet |
Logical. If |
A Fude Polygon data object with renamed elements.
read_fude()
path <- system.file("extdata", "castle.zip", package = "fude")
d <- read_fude(path, quiet = FALSE)
d2 <- rename_fude(d)
d2 <- rename_fude(d, suffix = FALSE)
d2 <- rename_fude(d, romaji = "upper")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.