Skip to contents

Prepares a Leaflet map for Fude Polygon data.

Usage

shiny_fude(data, height = 1000, rcom = FALSE)

Arguments

data

A list or data frame containing Fude Polygon data.

height

Height of the map.

rcom

A logical value indicating whether to overlay community data on the map.

Value

A Leaflet map object with Fude Polygon data with an HTML table.